Projects per language
=====================

This page lists all projects found by searching 'gnucash' on github (generated on 2014-12-28 23:01:40) excluding mirrors of the gnucash repository. Projects with a '\*' are projectsthat have not been updated since 12 months.

+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                     Language                     |                  # of projects                   |     # of projects updated in last 12 months      |
+==================================================+==================================================+==================================================+
|                  :ref:`Python`                   |                        51                        |                        39                        |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Perl`                    |                        12                        |                        12                        |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Java`                    |                        14                        |                        7                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                :ref:`JavaScript`                 |                        7                         |                        7                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`PHP`                    |                        9                         |                        7                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                  :ref:`Unknown`                  |                        11                        |                        7                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Shell`                   |                        7                         |                        5                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                     :ref:`C`                     |                        3                         |                        3                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                  :ref:`Scheme`                   |                        3                         |                        3                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`C#`                     |                        2                         |                        2                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`C++`                    |                        2                         |                        2                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Ruby`                    |                        6                         |                        2                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Scala`                   |                        2                         |                        2                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`Go`                     |                        1                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`Tcl`                    |                        1                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                  :ref:`Groovy`                   |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+

.. _Python:

Python
------

`alchemy <https://github.com/zmoog/alchemy>`__ by zmoog (last updated on  2014-03-06)
	A very simple Gnucash-inspired web application
`django-openbudget <https://github.com/evandavey/django-openbudget>`__ by evandavey (last updated on  2014-07-31)
	Simple django-based personal budgeting app that sources data from GNUCash sqlite data files
\* `DnbNor2qif <https://github.com/djiti/DnbNor2qif>`__ by djiti (last updated on  2013-08-26)
	Turning DnbNor CSV files into GNUCash-compatible QIF files
`dropcopy <https://github.com/juniorbl/dropcopy>`__ by juniorbl (last updated on  2014-06-10)
	A simple tool for GNOME to copy a given GnuCash file to a local dropbox directory whenever it is saved.
`ebay2gnucash <https://github.com/EvansMike/ebay2gnucash>`__ by EvansMike (last updated on  2014-09-30)
	Takes ebay mails and creates invoices or bills.
`financial_forecast <https://github.com/skullspace/financial_forecast>`__ by skullspace (last updated on  2014-12-15)
	A script to take in our Gnucash books and output a CSV with some historical and forecasted data
`flux <https://github.com/marcotmarcot/flux>`__ by marcotmarcot (last updated on  2014-09-27)
	Create a monthly flux report from a gnucash file
`gcimport <https://github.com/nblock/gcimport>`__ by nblock (last updated on  2014-01-12)
	Convert various input files (csv, txt) to csv files that can be easily parsed with GnuCash.
`gcinvoice <https://github.com/ngiger/gcinvoice>`__ by ngiger (last updated on  2014-10-02)
	GnuCash to Lates (see http://www.smoerz.org/gcinvoice/) + my personal templates
`gnc_privat24 <https://github.com/gentoo90/gnc_privat24>`__ by gentoo90 (last updated on  2014-12-18)
	Imports Privat24 statements to Gnucash book
`gnucash-cfdi <https://github.com/sebastianavina/gnucash-cfdi>`__ by sebastianavina (last updated on  2014-08-02)
	Proyecto que timbra facturas de gnucash por medio de facturacion moderna.
`gnucash-fiximports <https://github.com/sandeepmukherjee/gnucash-fiximports>`__ by sandeepmukherjee (last updated on  2014-09-08)
	Change target accounts of imported gnucash transactions
`gnucash-import <https://github.com/manzato/gnucash-import>`__ by manzato (last updated on  2014-07-15)
	Imports transactions from a CSV file and places them to the appropriate account depending on a set of rules
`gnucash-importers <https://github.com/rtucker/gnucash-importers>`__ by rtucker (last updated on  2014-12-07)
	gnucash importer scripts for Interlock Rochester financial foo
`gnucash-latex <https://github.com/mwellnitz/gnucash-latex>`__ by mwellnitz (last updated on  2014-11-06)
	Create good looking invoices for gnucash using latex and python
\* `gnucash-ofx-brokerage <https://github.com/7max/gnucash-ofx-brokerage>`__ by 7max (last updated on  2013-10-20)
	GnuCash OFX importer that handles brokerages, ie stocks, mutual funds, optios
`gnucash-ofx-export <https://github.com/hoffie/gnucash-ofx-export>`__ by hoffie (last updated on  2014-07-13)
	Selectively export GnuCash transactions into OFX
`gnucash-python-free <https://github.com/tbhartman/gnucash-python-free>`__ by tbhartman (last updated on  2014-08-23)
	(No description available)
`gnucash-qif <https://github.com/larsborn/gnucash-qif>`__ by larsborn (last updated on  2014-11-29)
	small set of python scripts to create a qif-file that can be imported to GnuCash
`gnucash-qif-import <https://github.com/hjacobs/gnucash-qif-import>`__ by hjacobs (last updated on  2014-12-10)
	GnuCash Python helper script to import transactions from QIF text files into GnuCash's own file format
\* `gnucash-rest <https://github.com/loftx/gnucash-rest>`__ by loftx (last updated on  2013-10-30)
	A Python based REST framework for the Gnucash accounting application
\* `gnucash-society <https://github.com/hendrikvanantwerpen/gnucash-society>`__ by hendrikvanantwerpen (last updated on  2013-11-02)
	Support application for societies based on GnuCash
`gnucash-stock-portfolio <https://github.com/hjacobs/gnucash-stock-portfolio>`__ by hjacobs (last updated on  2014-12-10)
	GnuCash Python utilities to manage a stock portfolio
\* `gnucash-tools <https://github.com/dahnielson/gnucash-tools>`__ by dahnielson (last updated on  2013-11-30)
	Tools for working with GnuCash
`gnucash-toolset <https://github.com/cirrax/gnucash-toolset>`__ by cirrax (last updated on  2014-12-11)
	Access and manipulate gnucash data.
`gnucash-util <https://github.com/bstpierre/gnucash-util>`__ by bstpierre (last updated on  2014-05-02)
	Utility scripts using GnuCash python bindings
`gnucash-xml-split <https://github.com/fefe982/gnucash-xml-split>`__ by fefe982 (last updated on  2014-08-26)
	Split GnuCash XML files into files containing transaction in a certain period (e.g. a year)
\* `gnucash2iif <https://github.com/pawl/gnucash2iif>`__ by pawl (last updated on  2013-08-18)
	Converts a Gnucash general ledger to an IIF file (for quickbooks)
`gnucash_balance_report <https://github.com/tbhartman/gnucash_balance_report>`__ by tbhartman (last updated on  2014-07-24)
	get balance report from gnucash file
`gnucash_django <https://github.com/RobFisher/gnucash_django>`__ by RobFisher (last updated on  2014-04-09)
	GnuCash Web Interface using Django.
`gnucash_explorer <https://github.com/peap/gnucash_explorer>`__ by peap (last updated on  2014-04-27)
	Another option for exploring your gnucash database
`gnucash_exports <https://github.com/jjuanda/gnucash_exports>`__ by jjuanda (last updated on  2014-01-13)
	GnuCash export scripts into several DBs/file formats
\* `gnucash_ofx <https://github.com/gevious/gnucash_ofx>`__ by gevious (last updated on  2013-12-20)
	Convert gnucash xml file to set of OFX files
`gnucash_python <https://github.com/davidjo/gnucash_python>`__ by davidjo (last updated on  2014-10-13)
	gnucash report writing in python
\* `gnucash_scripts <https://github.com/vrih/gnucash_scripts>`__ by vrih (last updated on  2013-09-10)
	(No description available)
\* `gnucashreports <https://github.com/youngchul/gnucashreports>`__ by youngchul (last updated on  2013-11-29)
	(No description available)
`gnucashxml <https://github.com/jorgenschaefer/gnucashxml>`__ by jorgenschaefer (last updated on  2014-08-22)
	Python library to read GNU Cash XML files
\* `hackerspace-gnucash <https://github.com/cvonkleist/hackerspace-gnucash>`__ by cvonkleist (last updated on  2013-10-16)
	Gainesville Hackerspace GnuCash scripts, etc.
\* `ing2gnucash <https://github.com/hjmeijer/ing2gnucash>`__ by hjmeijer (last updated on  2013-10-29)
	Converts downloaded ING (bank) transaction CSV files to GNUCash importable CSV
`ing2qif <https://github.com/marijnvriens/ing2qif>`__ by marijnvriens (last updated on  2014-10-17)
	Import ING bank statements and convert them to qif for importing into gnucash
`jeffs-gnucash-utils <https://github.com/n1ywb/jeffs-gnucash-utils>`__ by n1ywb (last updated on  2014-09-08)
	Jeff Laughlin's Python utilities for GnuCash. Includes HTML invoice generator.
\* `koert <https://github.com/awesterb/koert>`__ by awesterb (last updated on  2013-10-04)
	Toolbox for the inspection of GnuCash files for the kasco7 of Karpe Noktem
`masin <https://github.com/FelixAkk/masin>`__ by FelixAkk (last updated on  2013-12-28)
	A rework and GUI wrapping of the gcInvoice Python package for generating template based invoices from .gnucash data files.
`mbank2gnucash <https://github.com/h3xxx/mbank2gnucash>`__ by h3xxx (last updated on  2014-10-16)
	mBank transactions history to GnuCash converter
`ofxstatement <https://github.com/kedder/ofxstatement>`__ by kedder (last updated on  2014-11-12)
	Tool to convert proprietary bank statement to OFX format, suitable for importing to GnuCash.
`piecash <https://github.com/sdementen/piecash>`__ by sdementen (last updated on  2014-12-28)
	Pythonic interface to GnuCash SQL documents
`pygnclib <https://github.com/tdf/pygnclib>`__ by tdf (last updated on  2014-05-26)
	Pyxb-based read and write support for GnuCash XML files
`pygnucash <https://github.com/MatzeB/pygnucash>`__ by MatzeB (last updated on  2014-11-16)
	Python code to read gnucash 2.6 sqlite3 files
`Timetracker-to-Gnucash-Invoice <https://github.com/EvansMike/Timetracker-to-Gnucash-Invoice>`__ by EvansMike (last updated on  2014-07-22)
	Takes Anuko Timetracker data and creates an Invoice in GnuCash
`tws-gnucash <https://github.com/timwswanson/tws-gnucash>`__ by timwswanson (last updated on  2014-03-29)
	(No description available)
`visa-parser <https://github.com/pguridi/visa-parser>`__ by pguridi (last updated on  2014-01-08)
	A parser for the Visa pdf bill from www.visa.com.ar, useful for CSV import in Gnucash.

.. _C:

C
-

`gnucash-aqplus <https://github.com/jhs-s/gnucash-aqplus>`__ by jhs-s (last updated on  2014-05-02)
	Usually contains some fixes for aqbanking for GnuCash
`gnucash-svn <https://github.com/cstim/gnucash-svn>`__ by cstim (last updated on  2014-04-14)
	another clone of gnucash, but this time not using github's clone, and therefore keeping the svn metadata
`Lekhapala <https://github.com/kgrama/Lekhapala>`__ by kgrama (last updated on  2014-10-12)
	Personal accounting software that borrows features from gnucash and kmymoney

.. _C#:

C#
--

`gnucash2ledger-cli <https://github.com/marek-g/gnucash2ledger-cli>`__ by marek-g (last updated on  2014-08-05)
	Gnucash (general ledger html report) to ledger-cli converter.
`GnuCashReporter <https://github.com/Ettery/GnuCashReporter>`__ by Ettery (last updated on  2014-11-18)
	(No description available)

.. _C++:

C++
---

`gnucash-butchered <https://github.com/iulianu/gnucash-butchered>`__ by iulianu (last updated on  2014-10-23)
	My own butchered version of Gnucash
`UnderBudget <https://github.com/vimofthevine/UnderBudget>`__ by vimofthevine (last updated on  2014-10-03)
	Advanced personal budget analysis application that integrates with GnuCash, Quicken, mint.com, etc.

.. _Go:

Go
--

`gocash <https://github.com/remyoudompheng/gocash>`__ by remyoudompheng (last updated on  2014-12-15)
	gocash is a personal accounting interface similar to gnucash

.. _Groovy:

Groovy
------

\* `Zio-Antunello <https://github.com/masokotanga/Zio-Antunello>`__ by masokotanga (last updated on  2013-10-13)
	un gnucash online (?)

.. _Java:

Java
----

\* `androidcash <https://github.com/mbarbon/androidcash>`__ by mbarbon (last updated on  2013-09-29)
	Simple Android GnuCash companion
`BudgetReportGnuCash <https://github.com/martinlong1978/BudgetReportGnuCash>`__ by martinlong1978 (last updated on  2014-04-23)
	Jasper Budget Report for GnuCash
`gnc4a <https://github.com/bwduncan/gnc4a>`__ by bwduncan (last updated on  2014-11-22)
	GnuCash Companion for Android is an mobile application for devices running Google’s Android operating system, which will enable the users of GnuCash to do small things like adding a transaction or creating an invoice or expense voucher on the go.
\* `gnc4a <https://github.com/glennji/gnc4a>`__ by glennji (last updated on  2013-10-20)
	Gnucash for Android
`gnucash-android <https://github.com/codinguser/gnucash-android>`__ by codinguser (last updated on  2014-12-26)
	Gnucash for Android mobile companion application. 
`GnuCashBudgetReport <https://github.com/bvitale/GnuCashBudgetReport>`__ by bvitale (last updated on  2014-04-18)
	A budget report for GnuCash data that is stored in MySQL.
\* `gnucashMobile <https://github.com/nhrdl/gnucashMobile>`__ by nhrdl (last updated on  2013-10-19)
	(No description available)
\* `GnuCashToQIF <https://github.com/davidkgerman/GnuCashToQIF>`__ by davidkgerman (last updated on  2013-11-29)
	(No description available)
`GnuCashViewer <https://github.com/jrmcsoftware/GnuCashViewer>`__ by jrmcsoftware (last updated on  2014-03-03)
	GnuCash Viewer
\* `javacash <https://github.com/nhrdl/javacash>`__ by nhrdl (last updated on  2013-08-09)
	Yet another implementation of gnucash in Java
`jgnash-converter <https://github.com/kmbnw/jgnash-converter>`__ by kmbnw (last updated on  2014-05-08)
	A tool to convert from JGnash account XML files to other formats such as GnuCash.  Still in development; right now it just prints the accounts and transaction info to the screen.
\* `jgnucashlib <https://github.com/tdf/jgnucashlib>`__ by tdf (last updated on  2013-09-28)
	jGnucashLib - a java access to GnuCash files
\* `nordea-to-gnucash <https://github.com/mohamedamer/nordea-to-gnucash>`__ by mohamedamer (last updated on  2013-12-08)
	(No description available)
`workspace_gnucash <https://github.com/won21kr1/workspace_gnucash>`__ by won21kr1 (last updated on  2014-04-16)
	(No description available)

.. _JavaScript:

JavaScript
----------

`finance_dashboard <https://github.com/manicolosi/finance_dashboard>`__ by manicolosi (last updated on  2014-03-09)
	A dashing dashboard to show financial information from GnuCash
`gnucash-django <https://github.com/nylen/gnucash-django>`__ by nylen (last updated on  2014-12-10)
	Simple Web frontend for GnuCash, using Django
`gnucash-viewer <https://github.com/drjeep/gnucash-viewer>`__ by drjeep (last updated on  2014-05-02)
	Web viewer for Gnucash using Python/Flask
`gnucash-web <https://github.com/mrkrstphr/gnucash-web>`__ by mrkrstphr (last updated on  2014-01-29)
	(No description available)
`gnucash_tools <https://github.com/draffensperger/gnucash_tools>`__ by draffensperger (last updated on  2014-01-07)
	GnuCash Utilities including a Cru Reimbursement Submitter
`profitcash-restful <https://github.com/TheProfitwareGroup/profitcash-restful>`__ by TheProfitwareGroup (last updated on  2014-12-09)
	ProfitCash-RESTful is a RESTful service providing accounts and transaction information based on imported from GnuCash into MongoDB data.
`skilap <https://github.com/sergeyksv/skilap>`__ by sergeyksv (last updated on  2014-01-24)
	Personal online applications, GnuCash clone and others

.. _PHP:

PHP
---

`buchungen <https://github.com/jungepiraten/buchungen>`__ by jungepiraten (last updated on  2014-12-04)
	Webinterface für gnucash-Datenbank mit Funktion zum Verifizieren von Buchungen
`cashonline-php-server <https://github.com/okovalov/cashonline-php-server>`__ by okovalov (last updated on  2014-10-07)
	Backend part for cashonline project (clone of gnucash)
\* `gnucash-htdocs <https://github.com/sss/gnucash-htdocs>`__ by sss (last updated on  2013-12-15)
	Gnucash Website
`gnucash-php <https://github.com/cebe/gnucash-php>`__ by cebe (last updated on  2014-08-04)
	A library for reading gnucash XML format in PHP
\* `gnucash-tools <https://github.com/cccmzwi/gnucash-tools>`__ by cccmzwi (last updated on  2013-12-16)
	Convert your onlinebanking-export (CSV) to a neatly pre-categorized QIF-File which can be imported in Quicken or Gnucash
`gnucash.cakephp <https://github.com/claudineimatos/gnucash.cakephp>`__ by claudineimatos (last updated on  2014-06-25)
	(No description available)
`GnuCashPHP <https://github.com/mrBussy/GnuCashPHP>`__ by mrBussy (last updated on  2014-10-03)
	(No description available)
`gnucashreports <https://github.com/pedroabel/gnucashreports>`__ by pedroabel (last updated on  2014-08-04)
	Set of custom reports that I use for my personal finances. To see the reports working on a sample database, check the website http://gnucashreports.comuf.com/ ATTENTION: many problems yet. Many bugs that did not happen in my computer happened in this sample server.
`php-gnucash <https://github.com/mrkrstphr/php-gnucash>`__ by mrkrstphr (last updated on  2014-01-01)
	(No description available)

.. _Perl:

Perl
----

`Finance--Quote--YahooJapan <https://github.com/LiosK/Finance--Quote--YahooJapan>`__ by LiosK (last updated on  2014-09-08)
	A Perl module that enables GnuCash to get quotes of Japanese stocks and funds from Yahoo! JAPAN.
`finance-bomse <https://github.com/abhijit86k/finance-bomse>`__ by abhijit86k (last updated on  2014-09-09)
	A Perl module for fetching quotes for Indian stocks, intended for use with gnucash
`gc2latex <https://github.com/wertarbyte/gc2latex>`__ by wertarbyte (last updated on  2014-09-08)
	create pretty Gnucash invoices with LaTeX and Perl
`gnucash-importer <https://github.com/AloisMahdal/gnucash-importer>`__ by AloisMahdal (last updated on  2014-09-09)
	Import CSV data from arbitrary bank format to CSV acceptable by GnuCash
`gnucash-perl <https://github.com/goblin/gnucash-perl>`__ by goblin (last updated on  2014-09-08)
	Perl modules for reading and writing the Gnucash XML file
`GnuCash-SQLite <https://github.com/hoekit/GnuCash-SQLite>`__ by hoekit (last updated on  2014-11-15)
	A perl module to access GnuCash SQLite files.
`gnucash2mysql <https://github.com/xaprb/gnucash2mysql>`__ by xaprb (last updated on  2014-09-09)
	Gnucash to MySQL export script.
`MoneyDance-GnuCash-Importer <https://github.com/ets/MoneyDance-GnuCash-Importer>`__ by ets (last updated on  2014-12-06)
	Script to convert GnuCash data into a native MoneyDance XML file format
`MumbaiStock <https://github.com/geetuvaswani/MumbaiStock>`__ by geetuvaswani (last updated on  2014-09-09)
	Perl Module to fetch Bombay Stock Exchange bhavcopy for Indian Stocks for use with gnucash
`Paypal-csv-to-qif-converter <https://github.com/sonologic/Paypal-csv-to-qif-converter>`__ by sonologic (last updated on  2014-09-08)
	Converts paypal .csv to qif for importing in gnucash
`perl-gnucash-reader <https://github.com/hoekit/perl-gnucash-reader>`__ by hoekit (last updated on  2014-09-09)
	(No description available)
`tikzdipa <https://github.com/vimdude/tikzdipa>`__ by vimdude (last updated on  2014-12-21)
	GnuCash online quote source using Yahoo api

.. _Ruby:

Ruby
----

\* `accounting <https://github.com/freegeek-pdx/accounting>`__ by freegeek-pdx (last updated on  2013-12-04)
	accounting utilities for xtuple import and allocation in xtuple and gnucash
`gnucash-invoice <https://github.com/ixti/gnucash-invoice>`__ by ixti (last updated on  2014-12-02)
	Easy to use invoice printer for GnuCash.
\* `gnucash-rb <https://github.com/vbatts/gnucash-rb>`__ by vbatts (last updated on  2013-09-18)
	Ruby access to Gnucash SQL database
\* `gnucash2ledger <https://github.com/xaviershay/gnucash2ledger>`__ by xaviershay (last updated on  2013-12-23)
	Convert GnuCash files to a format supported by the ledger command line application
\* `gnucash_export <https://github.com/alibby/gnucash_export>`__ by alibby (last updated on  2013-12-01)
	Export gnucash data to sqlite/ csv
`ruby-gnucash <https://github.com/holtrop/ruby-gnucash>`__ by holtrop (last updated on  2014-11-10)
	Ruby library for extracting data from GnuCash data files

.. _Scala:

Scala
-----

`gnucash-quotes <https://github.com/akorneev/gnucash-quotes>`__ by akorneev (last updated on  2014-12-20)
	(No description available)
`gnucash-stuff <https://github.com/crankydillo/gnucash-stuff>`__ by crankydillo (last updated on  2014-01-18)
	(No description available)

.. _Scheme:

Scheme
------

`gc-decl-reports <https://github.com/yawaramin/gc-decl-reports>`__ by yawaramin (last updated on  2014-02-09)
	GnuCash declarative reports
`gnucash-account-balance-chart <https://github.com/timabell/gnucash-account-balance-chart>`__ by timabell (last updated on  2014-09-15)
	account balance line chart for gnucash
`gnucash-reports <https://github.com/trailbound/gnucash-reports>`__ by trailbound (last updated on  2014-09-28)
	Custom set of gnucash reports, currently in development.

.. _Shell:

Shell
-----

`archlinux-gnucash-latest <https://github.com/nengxu/archlinux-gnucash-latest>`__ by nengxu (last updated on  2014-12-21)
	Archlinux AUR package building scripts for latest Gnucash
\* `gnucash-docs <https://github.com/sss/gnucash-docs>`__ by sss (last updated on  2013-12-25)
	Manual and User Guide for Gnucash, the open-source accounting program
`gnucash-on-osx <https://github.com/jralls/gnucash-on-osx>`__ by jralls (last updated on  2014-12-21)
	Build GnuCash on OSX without X11
`gnucash-on-windows <https://github.com/Gnucash/gnucash-on-windows>`__ by Gnucash (last updated on  2014-12-19)
	Support scripts to build gnucash for Windows using mingw32.
`gnucash-on-windows <https://github.com/gjanssens/gnucash-on-windows>`__ by gjanssens (last updated on  2014-09-09)
	Support scripts to build gnucash for Windows using mingw32.
\* `LittleBudget <https://github.com/kstripp/LittleBudget>`__ by kstripp (last updated on  2013-09-30)
	Little Budget Tool for GNUCash
`nordea2ofx <https://github.com/nsrosenqvist/nordea2ofx>`__ by nsrosenqvist (last updated on  2014-10-24)
	A quick implementation of a converter between Nordea's CSV export to OFX so that it can be imported into various applications, such as Homebank or GnuCash. Only supporting Swedish and my edge cases, please consider improving the script and send a pull request for the changes.

.. _Tcl:

Tcl
---

`pycash <https://github.com/EvansMike/pycash>`__ by EvansMike (last updated on  2014-09-13)
	Some Python utilites that GnuCash users may find useful.

.. _Unknown:

Unknown
-------

`accounting <https://github.com/communotey/accounting>`__ by communotey (last updated on  2014-05-18)
	Accounting for Communote, using GNUCash
\* `an-gnucash <https://github.com/wanjing/an-gnucash>`__ by wanjing (last updated on  2013-01-11)
	android app for gnucash
\* `GCtranslate <https://github.com/AshokR/GCtranslate>`__ by AshokR (last updated on  2013-06-15)
	GnuCash Translation
\* `GnuCash-3part-check <https://github.com/agh1/GnuCash-3part-check>`__ by agh1 (last updated on  2013-10-17)
	A 3-part check format for GnuCash
`gnucash-api <https://github.com/jjuanda/gnucash-api>`__ by jjuanda (last updated on  2014-02-02)
	REST APIs for GnuCash files
`gnucash-export <https://github.com/deonbredenhann/gnucash-export>`__ by deonbredenhann (last updated on  2014-06-19)
	Export GnuCash to csv
`gnucash-mysql-additions <https://github.com/ohingardail/gnucash-mysql-additions>`__ by ohingardail (last updated on  2014-09-09)
	Custom MySql functions to add useful functions to GnuCash
`gnucash-rest <https://github.com/mhitchens/gnucash-rest>`__ by mhitchens (last updated on  2014-05-03)
	A Spring Data/Spring REST interface to a gnucash data file
`hGnucash <https://github.com/pharaun/hGnucash>`__ by pharaun (last updated on  2014-12-19)
	Haskell xml library for parsing the gnucash file format
`nordea-csv2qif <https://github.com/martinolsen/nordea-csv2qif>`__ by martinolsen (last updated on  2014-06-11)
	Convert Nordea CSV exports to QIF format (usable by GnuCash and others)
\* `rabo2qif <https://github.com/milovanderlinden/rabo2qif>`__ by milovanderlinden (last updated on  2013-12-13)
	export mut.txt to qif for gnucash

